pub struct LoadedPlugin {
pub manifest: PluginManifest,
pub root_dir: PathBuf,
pub namespace: String,
pub source: PluginSource,
pub components: ResolvedComponents,
}Expand description
A plugin that successfully passed manifest validation and platform/version
gating. components is already resolved to absolute paths under root_dir.
Fields
manifest: PluginManifestParsed manifest.
root_dir: PathBufAbsolute path to the plugin directory.
namespace: StringNamespace string — always == manifest.name. Kept separately for
quick access by overlays.
source: PluginSourceSource root the plugin was discovered in.
components: ResolvedComponentsComponent paths resolved against root_dir.
Implementations
Sourceimpl LoadedPlugin
impl LoadedPlugin
Sourcepub fn namespace_item(&self, bare: &str) -> String
pub fn namespace_item(&self, bare: &str) -> String
Compose <namespace>:<bare> for a discovered item.